/**
 * 5+http请求，依赖plus对象，可跨域，多状态管理
 * kevinE QQ:202165023
 * v2.0 2022-4-15 14:17:59
 */

// 请求超时时间 秒
const TIMEOUT = '5';
// 内容传输时间 秒
const PROGRESS = '5';

/**
 * @typedef {Object} HttpOptions
 * @type {Object.<String>}
 * @property {String} url 请求地址 
 * @property {"GET"|"POST"} [method] 请求地址 
 * @property {JSON} [header] 请求头 
 * @property {JSON} [data] 请求参数
 * @property {Function} [success] 成功回调
 * @property {Function} [abnormal] 异常回调
 * @property {Function} [fail] 失败回调
 * @property {Function} [error] 错误回调
 */

/**
 * @description 发送网络请求
 * @param {
	 url {String} url
	 method {String} method
 }
 * @return {JSON} 请求结果
 */
function http({
	url = null,
	method = 'GET',
	header = {},
	data = {},
	success = null,
	abnormal = null,
	fail = null,
	error = null,
}) {
	let _data = '';
	for (let item in data) {
		_data = '&' + item + '=' + data[item];
	}
	_data = _data.substr(1);
	let _url = method == 'GET' ? url+'?'+data : url ;
	
	// 准备网络请求
	let xhr = new plus.net.XMLHttpRequest();
	if (method !== 'GET') xhr.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');
	let _header = '';
	for (let item in header) {
		xhr.setRequestHeader(item, header[item]);
	}
	xhr.timeout = TIMEOUT * 1000;
	xhr.onerror = () => {
		fail && fail(xhr);
	}
	// 监听请求状态变化
	xhr.onreadystatechange = () => {
		console.log(xhr);
		if (xhr.readyState == 4) {
			// xhr_complete = 1;
			if (xhr.status == 200) {
				console.log(xhr);
				let res;
				try {
					res = JSON.parse(xhr.responseText);
				} catch(e) {
					error && error(e);
					return;
				}
				success && success(res);
			}
			else abnormal && abnormal(xhr);
		}
	}
	xhr.open(method, _url);
	xhr.send(data)
}
